﻿using System;
using System.Collections;
using System.Configuration;
using System.Data;
using System.Linq;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Xml.Linq;
using GenericParsing;
using SoftArtisans.OfficeWriter.WordWriter;

namespace BusinesLabels
{
    public partial class Part1 : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {

        }

        protected void RunReport_Click(object sender, EventArgs e)
        {
            try
            {
                BindTemplateData();
            }
            catch (Exception ex)
            {
                ErrorLabel.Visible = true;
                //If OfficeWriter isn't installed, show this error message
                if (ex.Message.Contains("General license key exception"))
                {
                    ErrorLabel.Text = "OfficeWriter does not appear to be" +
                       " installed on this machine. If you have not " +
                       "purchased OfficeWriter, you can download the " +
                       "evaluation version here: " +
                       "http://www.officewriter.com/officewriter-free-evaluation.aspx";
                }
                else
                {
                    ErrorLabel.Text = ex.Message;
                }
            }
        }

        private void BindTemplateData()
        {
            //Instantiate a new WordTemplate object
            WordTemplate WT = new WordTemplate();

            //NEXT fields will be ignored by default
            //This must be set before Open() is called
            WT.EnableNEXTFields = true;

            //Open the template file
            WT.Open(Page.MapPath("//templates//Business_Label_template.docx"));

            //Get the employee info datatable using GenericParser
            DataTable dtBusinessLabels = GetCSVData("//data//BusinessLabelTutorialData.csv");

            //Set the data sources to import a single row of data for each source
            WT.SetMailMerge(dtBusinessLabels);

            //Process to import the data to the template
            WT.Process();

            WT.Save(Page.Response, "Business_Labels_Output.docx", false);

        }

        #region Utility Methods
        /// <summary>
        /// Helper method that uses CSVParser
        /// </summary>
        /// <param name="filename">Filename of CSV</param>
        /// <returns>Populated DataTable</returns>
        protected DataTable GetCSVData(string filename)
        {
            DataTable dt = new DataTable();
            using (GenericParserAdapter parser = new GenericParserAdapter(Page.MapPath(filename)))
            {
                parser.ColumnDelimiter = ',';
                parser.FirstRowHasHeader = true;

                dt = parser.GetDataTable();
            }
            return dt;
        }

        #endregion
    }
}
